This function generates a Markov chain sample from a multivariate normal distribution using a two-block Gibbs sampler. The function is used mainly for implementation in the examples of this package.
mvn.gibbs(N = 10000, p, mu, sigma)N by p matrix of samples from the multivariate normal target distribution
number of Markov chain samples desired
dimension of the multivariate normal target distribution
mean vector of the multivariate normal distribution
covariance matrix of the multivariate normal distribution